<?php
/**
 * Name: Float Payment Details
 * URI: https://float.com
 * Description: Display Float payment details on products
 * Author: © FLOAT TECHNOLOGIES (PTY) LTD
 * Author URI: http://float.co.za
 * Version: 1.0.0
 */

namespace float\frontend;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

add_action('woocommerce_loaded', function () {
    new FloatUI();
});

class FloatUI
{
    function __construct()
    {
        add_action('woocommerce_single_product_summary', [$this, 'paymentLightBox'], 15);
        add_action('wp_enqueue_scripts', function () {
            wp_enqueue_style('floatStyle', plugins_url('assets/css/float.css', __FILE__));
            wp_register_script('featherliteScript', plugins_url('assets/js/featherlite.js', __FILE__), array('jquery'));
            wp_enqueue_script('featherliteScript');
        });
        add_filter('wp_kses_allowed_html', [$this, 'allow_iframe_wpkses_post'], 10, 2);
        add_filter('safe_style_css', [$this, 'allow_display_wpkses_post']);
    }

    public function paymentLightBox()
    {
        if (wc_get_product(get_the_ID())) {
            $product = wc_get_product(get_the_ID());
            $floatprice = wc_get_price_including_tax($product);
            if ($floatprice) {

                // set term and from amount
                $maxTerm = 4;

                $floatone = $floatprice / $maxTerm;
                $floatone = ceil($floatone * 100) / 100;
                //Variable product data saved for updating amount when selection is made
                if ($product->is_type('variable')) {
                    $variations_data = [];
                    foreach ($product->get_available_variations() as $variation) {
                        $varprice = $variation['display_price'] / $maxTerm;
                        $varprice = ceil($varprice * 100) / 100;
                        $variations_data[$variation['variation_id']] = wc_price($varprice);
                    }
?>
                    <script>
                        jQuery(function($) {
                            $('#vprodtextupdate').text('from');
                            var jsonData = <?php echo wp_json_encode($variations_data); ?>,
                                inputVID = 'input.variation_id';
                            $('input.variation_id').change(function() {
                                if ('' != $(inputVID).val()) {
                                    var vid = $(inputVID).val(),
                                        vprice = '';
                                    $.each(jsonData, function(index, price) {
                                        if (index == vid) {
                                            vprice = price;
                                        }
                                    });
                                    $('#vprodtextupdate').text('of');
                                    $('#vprodpriceupdate').html(vprice);
                                }
                            });
                        });
                    </script>
<?php
                }

                $img = plugins_url('assets/images/float-logo.png', __FILE__);
                // Model content
                $content = '<div><iframe src="https://secure.float.co.za/home/how-to-float#no-scroll" style="max-width:100%;" width="800" height="850"></iframe></div>';
                // Display modal / trigger
                $html = '<div class="float-lightbox" style="line-height: 1.6;">';
                $html .= '<img src="' . $img . '" alt="Float" />';
                $html .= 'Or as low as <span id="vprodpriceupdate" class="float-highlight">' . wc_price($floatone) . '</span> over <span class="float-highlight"> ' . $maxTerm . ' months interest-free</span>, using your existing credit card. <a href="#" data-featherlight="#floatLightbox" style="text-decoration:underline !important;">How it works</a>';
                $html .= '<div style="display:none;"><div id="floatLightbox">' . $content . '</div></div>';
                $html .= '<div class="float-clear"></div>';
                $html .= '</div>';
                $html .= '';
                echo wp_kses_post($html);
            }
        }
    }
    // Allow iframes in sanitized data
    public function allow_iframe_wpkses_post($tags, $context)
    {
        if ('post' === $context) {
            $tags['iframe'] = array(
                'src'             => true,
                'height'          => true,
                'width'           => true,
                'frameborder'     => true,
                'allowfullscreen' => true,
                'style' => true,
            );
        }
        return $tags;
    }
    public function allow_display_wpkses_post($styles)
    {
        $styles[] = 'display';
        return $styles;
    }
}
